"use strict";
var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
var events_1 = require('../serenity/domain/events');
var model_1 = require('../serenity/domain/model');
var serenity_1 = require('../serenity/serenity');
var cucumber = require('cucumber');
function scenarioLifeCycleNotifier() {
    return Object.assign(cucumber.Listener(), {
        handleBeforeScenarioEvent: handleBeforeScenarioEvent,
        handleBeforeStepEvent: handleBeforeStepEvent,
        handleStepResultEvent: handleStepResultEvent,
        handleScenarioResultEvent: handleScenarioResultEvent,
    });
    // handleAfterStepEvent      (step: events.StepPayload, callback: () => void) => callback();
    // handleBeforeFeaturesEvent (features: events.FeaturesPayload, callback: () => void) => callback();
    // handleBeforeFeatureEvent  (feature: events.FeaturePayload, callback: () => void) => callback();
    // handleAfterScenarioEvent  (scenario: events.ScenarioPayload, callback: () => void) => callback();
    // handleAfterFeatureEvent   (feature: events.FeaturePayload, callback: () => void) => callback();
    // handleFeaturesResultEvent (featuresResult: events.FeaturesResultPayload, callback: () => void) => callback();
    // handleAfterFeaturesEvent  (features: events.FeaturesPayload, callback: () => void) => callback();
}
exports.scenarioLifeCycleNotifier = scenarioLifeCycleNotifier;
function handleBeforeScenarioEvent(scenario, callback) {
    serenity_1.Serenity.notify(new events_1.SceneStarts(sceneFrom(scenario)));
    callback();
}
function handleBeforeStepEvent(step, callback) {
    if (!step.isHidden()) {
        serenity_1.Serenity.notify(new events_1.ActivityStarts(activityFrom(step)));
    }
    callback();
}
function handleStepResultEvent(result, callback) {
    var step = result.getStep();
    // "before" and "after" steps emit an event even if they keywords themselves are not present in the test...
    if (!step.isHidden()) {
        serenity_1.Serenity.notify(new events_1.ActivityFinished(outcome(activityFrom(step), result.getStatus(), result.getFailureException())));
    }
    callback();
}
function handleScenarioResultEvent(result, callback) {
    var scenario = result.getScenario();
    serenity_1.Serenity.notify(new events_1.SceneFinished(outcome(sceneFrom(scenario), result.getStatus(), result.getFailureException())));
    callback();
}
// --
function sceneFrom(scenario) {
    return new CucumberScene(scenario);
}
function activityFrom(step) {
    return new model_1.Activity(step.getKeyword() + step.getName());
}
function outcome(subject, status, error) {
    return new model_1.Outcome(subject, serenityResultFrom(status), error);
}
function serenityResultFrom(status) {
    var results = {
        // 'ambiguous':       // todo: do we care? will cucumber ever tell us about ambiguous steps?'
        'undefined': model_1.Result.PENDING,
        'failed': model_1.Result.FAILURE,
        'pending': model_1.Result.PENDING,
        'passed': model_1.Result.SUCCESS,
        'skipped': model_1.Result.SKIPPED,
    };
    if (!results[status]) {
        throw new Error("Couldn't map the '" + status + "' to a Serenity Result");
    }
    return results[status];
}
function toSerenityTag(cucumberTag) {
    return model_1.Tag.from(cucumberTag.getName());
}
var CucumberScene = (function (_super) {
    __extends(CucumberScene, _super);
    function CucumberScene(scenario) {
        _super.call(this, scenario.getName(), scenario.getFeature().getName(), scenario.getUri(), scenario.getTags().map(toSerenityTag), scenario.getFeature().getName() + ":" + scenario.getLine() + ":" + scenario.getName());
    }
    return CucumberScene;
}(model_1.Scene));

//# sourceMappingURL=cucumber_serenity_notifier.js.map
