"use strict";
var Target = (function () {
    function Target(name, locator) {
        this.name = name;
        this.locator = locator;
    }
    Target.the = function (name) {
        return new TargetBuilder(name);
    };
    Target.prototype.of = function () {
        var tokenReplacements = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            tokenReplacements[_i - 0] = arguments[_i];
        }
        return new Target(this.name, new Interpolated(this.locator).with(tokenReplacements));
    };
    Target.prototype.called = function (newName) {
        return new Target(newName, this.locator);
    };
    Target.prototype.resolveUsing = function (resolver) {
        return resolver(this.locator);
    };
    Target.prototype.resolveAllUsing = function (resolver) {
        return resolver.all(this.locator);
    };
    Target.prototype.toString = function () {
        return "the " + this.name;
    };
    return Target;
}());
exports.Target = Target;
var Interpolated = (function () {
    function Interpolated(locator) {
        this.locator = locator;
    }
    Interpolated.prototype.with = function (tokenReplacements) {
        // note: ProtractorBy is not compatible with WebdriverBy https://github.com/angular/protractor/issues/3508
        if (!this.canBeInterpolated()) {
            throw new Error(this.locator.toString() +
                ' is not a webdriver-compatible locator so you won\'t be able to use token replacement with it');
        }
        var cloned = Object.assign({}, this.locator);
        cloned.__proto__ = Object.getPrototypeOf(this.locator);
        cloned.value = this.interpolated(this.locator.value, tokenReplacements);
        return cloned;
    };
    Interpolated.prototype.canBeInterpolated = function () {
        return !!this.locator.value;
    };
    Interpolated.prototype.interpolated = function (template, replacements) {
        var argToken = /\\?\{(\d+)\\?\}/g, interpolator = function (token, field) { return replacements[field]; };
        return template.replace(argToken, interpolator);
    };
    return Interpolated;
}());
var TargetBuilder = (function () {
    function TargetBuilder(name) {
        this.name = name;
    }
    TargetBuilder.prototype.located = function (byLocator) {
        return new Target(this.name, byLocator);
    };
    TargetBuilder.prototype.toString = function () {
        return "TargetBuilder for the " + this.name;
    };
    return TargetBuilder;
}());
exports.TargetBuilder = TargetBuilder;

//# sourceMappingURL=target.js.map
