"use strict";
var model_1 = require('../domain/model');
var StepDescription = (function () {
    function StepDescription(template) {
        this.template = template;
        this.argToken = /{(\d+)}/g;
        this.fieldToken = /#(\w+)/g;
    }
    StepDescription.from = function (template) {
        return new StepDescription(template);
    };
    StepDescription.prototype.interpolateWith = function (performable, argumentsOfThePerformAsMethod) {
        var name = this.determineStepName(this.template, performable, argumentsOfThePerformAsMethod);
        return new model_1.Activity(name);
    };
    StepDescription.prototype.using = function (source) {
        return function (token, field) {
            switch ({}.toString.call(source[field])) {
                case '[object Function]': return source[field]();
                case '[object Array]': return source[field].join(', ');
                case '[object Object]': return source[field].toString();
                case '[object Undefined]': return token;
                default: return source[field];
            }
        };
    };
    StepDescription.prototype.determineStepName = function (template, performable, args) {
        return template.
            replace(this.fieldToken, this.using(performable)).
            replace(this.argToken, this.using(args));
    };
    return StepDescription;
}());
exports.StepDescription = StepDescription;

//# sourceMappingURL=step_description.js.map
